# -*- coding: latin-1 -*-
#    QUENLIG: Questionnaire en ligne (Online interactive tutorial)
#    Copyright (C) 2005-2006 Thierry EXCOFFIER, Universite Claude Bernard
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#    Contact: Thierry.EXCOFFIER@bat710.univ-lyon1.fr
#

from questions import *
from check import *

dumb_replace = ( ("-A", "-e"), )

add(name="intro",
    required=["sh:arrire plan"],
    question="""Quel est le nom de la commande permettant
    de lister des processus&nbsp;?""",
    tests=(
    good("ps"),
    good("pstree",
         "J'attendais la commande <tt>ps</tt> qui est standard."),
    bad("top",
        """Cette commande permet de surveiller les processus.
        Ce n'est pas ce qui vous ai demand"""),
    ),
    indices=("""Le nom de la commande est compos de la premire
    et de la dernire lettre du mot 'processus'""",
             ),
    )

add(name="tous",
    question="""Donnez l'option de la commande <tt>ps</tt> permettant de lister
    tous les processus qui fonctionnent sur la machine.""",
    tests=(
    good(("ps -e", "-e", "ps -A", "-A")),
    bad(("ps a", "a", "ps -a", "-a", "ps e", "e"),
        """Cette option n'affiche pas les processus systmes,
        seulement les votres"""),
    reject("pstree", "On vous parle de la commande <tt>ps</tt>"),
    ),
    )

add(name="init",
    question="""Quel est le <tt>PID</tt> du processus <tt>init</tt>&nbsp;?""",
    tests=(
    good("1"),
    require_int,
    ),
    )

add(name="compte",
    required=["tous", "compte:ligne", "pipeline:intro"],
    question="""Quelle est la commande la plus simple donnant le nombre
    de processus fonctionnant sur votre machine&nbsp;?""",
    tests=(
    shell_good("ps -e | wc -l", dumb_replace=dumb_replace ),
    shell_bad("ps -e | wc",
               """Il manque une option  <tt>wc</tt> pour qu'il n'affiche
               que le nombre de processus et pas le nombre de caractres
               et de mots.""",
               dumb_replace=dumb_replace ),
    require("ps",
            """Vous n'utilisez pas la commande affichant
            la liste des processus&nbsp;!"""),
    require("wc",
            """Vous n'utilisez pas la commande permettant de compter
            des lignes&nbsp;!"""),
    require("-e",
            """On veut le nombre de processus sur votre machine
            pas seulement ceux qui ont t lancs dans votre terminal.
            Il manque donc une option  <tt>ps</tt>"""),
    shell_display,
    ),
    )

add(name="trouver",
    required=["tous", "pipeline:intro", "cribler:simple"],
    before="""Lancez des applications graphiques en arrire plan&nbsp;:
    <pre>xeyes &amp;
xclock &amp;
xdaliclock &amp;</pre>""",
    question="""Donnez la ligne de commande affichant les informations
    sur les processus qui contiennent <tt>xeyes</tt> dans
    leur description (lanc par vous ou non).""",
    tests=(
    shell_good("ps -e | grep xeyes", dumb_replace=dumb_replace),
    shell_bad("ps | grep xeyes",
              """Cette commande ne va pas fonctionner si vous la lancez
              sur un terminal diffrent de celui utilis
              pour lancer <tt>xeyes</tt>.
              Il manque une option  la commande <tt>ps</tt>.
              """),
    shell_bad("ps -C xeyes",
              """<b>C'est tout  fait correcte</b>, mais cela n'affiche
              que les commandes dont le nom est <tt>xeyes</tt>.
              Cela n'affichera pas les commandes qui contiennent
              <tt>xeyes</tt> dans leur description.
              Le but de cet exercice est de vous faire utiliser
              un pipeline."""),              
    require("xeyes",
            "Votre commande ne fait pas rfrence  <tt>xeyes</tt>&nbsp;!"),
    require("ps",
            "Votre commande ne fait pas rfrence  <tt>ps</tt>&nbsp;!"),
    require("|",
            "Votre commande ne contient pas de pipeline."),
    shell_display,
    ),
    )

add(name="sauve pid",
    required=["trouver", "sh:deuxime mot"],
    question="""Stockez le PID du premier processus
    <tt>xeyes</tt> trouv dans la variable <tt>Z</tt>
    <p>
    Si vous avez besoin de variables, appelez les <tt>A</tt>, <tt>B</tt>, ...
    """,
    tests=(
    shell_good((
    "Z=$(ps -e | grep xeyes | (read A B ; echo $A))",
    'Z=$(ps -e | grep xeyes | (read A B ; echo "$A"))',
                ),
               dumb_replace=dumb_replace),
    shell_display,
    ),
    )

def test_kill(reponse, get_answer=False):
    if get_answer:
        return get_str_answer("test_good test_is",
                              ("kill PID",),
                              "")
    reponse = reponse.split(" ")
    if len(reponse) != 2:
        return False, """Il suffit de lancer la commande <tt>kill</tt>
        avec comme paramtre le PID du processus  tuer."""

    if reponse[0] != "kill":
        return False, "La commande s'appelle <tt>kill</tt>"
   
    try:
        i = int(reponse[1])
        return True, ""
    except ValueError:
        return False, "Vous devez donner le PID du processus"

add(name="tuer",
    before="""Lancez un application graphique en arrire plan&nbsp;:
    <pre>xeyes &
</pre>
L'entier affich est le PID du processus lanc.
""",
    required=["tous"],
    question="""Quelle commande lancez-vous pour tuer la commande
    <tt>xeyes</tt> en spcifiant son PID&nbsp;?
    <em>Donnez la ligne de commande complte</em>
    """,
    tests=(
    test_kill,
    ),
    )

add(name="tuer un shell",
    before="""Lancez un nouveau terminal,
    trouver le PID du shell en train de tourner dans
    ce terminal avec la commande <tt>ps</tt> (sans argument).
    <p>
    Essayez de tuer le shell en faisant <tt>kill SON_PID</tt>
""",
    required=["tuer"],
    question="""Quel argument faut-il ajouter  la commande <tt>kill</tt>
    pour pouvoir tuer un shell&nbsp;?""",
    tests=(
    good("-1"),
    good(("-s 1", "-HUP", "-s HUP"), "<tt>-1</tt> est plus court  taper"),
    reject("kill", """On veut seulement l'option  ajouter,
    pas la commande complte"""),
    reject("9",
           """Le signal <tt>9</tt> est extremement violent.
           Il ne demande pas au processus de se terminer proprement.
           Il n'est  utiliser qu'en dernier recours"""),
    require("-",
            "On veut une options, il y a donc un <tt>-</tt> quelque part."
            ),
    
    ),
    bad_answer="""Il faut envoyer le signal HUP (<em>hang up</em>)
    qui veut dire raccrocher la ligne et qui porte le numro <tt>1</tt>""",
    
    )

add(name="pstree",
    required=["tous"],
    before="""La commande <tt>pstree</tt> n'est pas standard
    mais bien pratique.
    Elle affiche la liste de tous les processus sous la forme
    d'un arbre de processus.""",
    question="""Quel est le nom du processus qui est
     la racine de la hirarchie des processus&nbsp;?""",
    tests=(
    good("init"),
    ),
    )

add(name="top",
    required=["tous"],
    before="""La commande <tt>top</tt> n'est pas standard
    mais bien pratique.
    Elle affiche priodiquement sur l'cran la liste
    de processus utilisant le plus de temps CPU actuellement.
    <p>
    Si vous tapez le caractre <tt>?</tt> cette commande
    vous affichera une page d'aide.
    """,
    question="""Quelle commande (dfinie par un seul caractre)
    utilisez-vous pour inverser la direction du tri&nbsp;?""",
    tests=(
    good("R"),
    bad("r", "Cette commande sert  changer la priorit d'un processus"),
    answer_length_is(1, "On vous a dit que la rponse tait sur 1 caractre"),
    ),
    )

